/*
* ==============================================================================
*  Name        : MAudioAdapter.h
*  Part of     : Sound Application
*  Interface   :
*  Description : Defines the audio adapter interface
*  Version     : 1
*
*  Copyright (c) 2006, Nokia Corporation All rights reserved. Redistribution
*  and use in source and binary forms, with or without modification, are
*  permitted provided that the following conditions are met: Redistributions
*  of source code must retain the above copyright notice, this list of
*  conditions and the following disclaimer. Redistributions in binary form
*  must reproduce the above copyright notice, this list of conditions and the
*  following disclaimer in the documentation and/or other materials provided
*  with the distribution. Neither the name of the Nokia Corporation nor the
*  names of its contributors may be used to endorse or promote products
*  derived from this software without specific prior written permission. THIS
*  SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
*  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
*  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
*  ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
*  LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
*  CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
*  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
*  INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
*  CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
*  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
*  POSSIBILITY OF SUCH DAMAGE.
* ==============================================================================
*/

// INCLUDE FILES
#ifndef __MAUDIOADAPTER__
#define __MAUDIOADAPTER__

#include <e32std.h>
#include <assert.h>


#define KAudioAdapterInterfaceUid 0x0020240E



class CEikMenuPane;

// CLASS DECLARATION

/**
*  This class defines the audio adapter interface.
*
*/
class MAudioAdapter
    {
	public:

        /**
        * Initiates playback using the audio utility
        */
		virtual void PlayL() = 0;

        /**
        * Pause the audio utility
        */
        virtual void PauseL() = 0;

        /**
        * Stops the audio utility
        */
        virtual void StopL() = 0;

		/**
	  	* Initiates Record using the audio utility
	  	*/
		virtual void RecordL() = 0;

	  	/*
	  	* Update the menu aMenuPane to reflect the current state of the audio utility.
	  	* @param aMenuPane the menu pane to update
	  	*/
		virtual void UpdateMenuL(CEikMenuPane* aMenuPane) = 0;

        /**
        * Add additional items to the specified menu
        * @param aMenuPane The menu pane to which items are added
        */
        virtual void AddExtraMenu(CEikMenuPane* aMenuPane) = 0;

        /**
        * Handles the commands from the UI
        * @param aCommand The command to be handled
        * @return ETrue if the command was handled, EFalse otherwise.
        */
		virtual TBool HandleCommandL(TInt aCommand) = 0;

        /**
        * Return an identifying string
        * @return An identification string
        */
		virtual const TDesC& Identify() const = 0;

        /**
        * Get number of supported metadata
        * @return Number of supported metada
        */
		virtual TInt SupportMetadata() const = 0;

        /**
        * Toggles between play and pause
        */
		virtual void TogglePlayPause() = 0;

       	/**
        * Set the volume
        * @param aVolume The desired volume level
        */
		virtual void SetVolume(TInt aVolume) = 0;

        /**
        * Get the current volume level
        * @return Volume Level
        */
		virtual TInt Volume() = 0;


	public: // Data

		enum TState
			{
			ENotReady, 		// Not ready to play
			EReadyToPlay,  	// Ready to play
			EPlaying		// playing
			};

		// state of the audio player utility
		TState iState;
    };

#endif // __MAUDIOADAPTER__

// End of File
